{% load i18n fb_versions %}
<div>
    {% for gallery in object_list %}
    <div class="columns small-6 medium-3 panel radius text-center{% if forloop.last %} end{% endif %}">
        <a href="{% url 'porticus:gallery-detail' gallery_slug=gallery.slug %}">
            {% if gallery.image %}
                {% version_object gallery.image 'thumbnail' as image_thumb %}
                <p><img src="{{ image_thumb.url }}" alt=""></p>
            {% endif %}
            <p>{{ gallery }}</p>
        </a>
    </div>
    {% empty %}
    <div class="text-center"><p class="empty">{% trans "No gallery" %}</p></div>
    {% endfor %}
</div>
